/********************************************************************************
 * Copyright (C) 2018 Ericsson and others.
 *
 * This program and the accompanying materials are made available under the
 * terms of the Eclipse Public License v. 2.0 which is available at
 * http://www.eclipse.org/legal/epl-2.0.
 *
 * This Source Code may also be made available under the following Secondary
 * Licenses when the conditions for such availability set forth in the Eclipse
 * Public License v. 2.0 are satisfied: GNU General Public License, version 2
 * with the GNU Classpath Exception which is available at
 * https://www.gnu.org/software/classpath/license.html.
 *
 * SPDX-License-Identifier: EPL-2.0 OR GPL-2.0 WITH Classpath-exception-2.0
 ********************************************************************************/
import { Emitter, Event } from '@devpodio/core';
import { CppPreferences } from './cpp-preferences';
import { StorageService } from '@devpodio/core/lib/browser/storage-service';
export interface CppBuildConfiguration {
    /** Human-readable configuration name.  */
    name: string;
    /** Base directory of this build.  */
    directory: string;
    /** List of commands for this build configuration.  */
    commands?: {
        'build'?: string;
    };
}
export declare const CppBuildConfigurationManager: unique symbol;
export interface CppBuildConfigurationManager {
    /** Get the list of defined build configurations.  */
    getConfigs(): CppBuildConfiguration[];
    /** Get the list of valid defined build configurations.  */
    getValidConfigs(): CppBuildConfiguration[];
    /** Get the active build configuration.  */
    getActiveConfig(): CppBuildConfiguration | undefined;
    /** Change the active build configuration.  */
    setActiveConfig(config: CppBuildConfiguration | undefined): void;
    /** Event emitted when the active build configuration changes.  */
    onActiveConfigChange: Event<CppBuildConfiguration | undefined>;
    /**
     * Promise resolved when the list of build configurations has been read
     * once, and the active configuration has been set, if relevant.
     */
    ready: Promise<void>;
}
export declare const CPP_BUILD_CONFIGURATIONS_PREFERENCE_KEY = "cpp.buildConfigurations";
/**
 * Entry point to get the list of build configurations and get/set the active
 * build configuration.
 */
export declare class CppBuildConfigurationManagerImpl implements CppBuildConfigurationManager {
    protected readonly cppPreferences: CppPreferences;
    protected readonly storageService: StorageService;
    /**
     * The current active build configuration.  undefined means there's not
     * current active configuration.
     */
    protected activeConfig: CppBuildConfiguration | undefined;
    /** Emitter for when the active build configuration changes.  */
    protected readonly activeConfigChangeEmitter: Emitter<CppBuildConfiguration | undefined>;
    readonly ACTIVE_BUILD_CONFIGURATION_STORAGE_KEY = "cpp.active-build-configuration";
    ready: Promise<void>;
    init(): Promise<void>;
    /** Load the active build config from the persistent storage.  */
    protected loadActiveConfiguration(): Promise<void>;
    /**
     * Save the active build config name to persistent storage.
     */
    protected saveActiveConfiguration(config: CppBuildConfiguration | undefined): void;
    getActiveConfig(): CppBuildConfiguration | undefined;
    setActiveConfig(config: CppBuildConfiguration | undefined): void;
    readonly onActiveConfigChange: Event<CppBuildConfiguration | undefined>;
    getConfigs(): CppBuildConfiguration[];
    getValidConfigs(): CppBuildConfiguration[];
}
//# sourceMappingURL=cpp-build-configurations.d.ts.map